from setuptools import setup

setup(name='gauss_and_bino_distributions',
      version='0.1',
      author='Yip Tuck Wai',
      author_email='yiptuckwai@yahoo.com',
      description='Gaussian and binomial distributions',
      packages=['gauss_and_bino_distributions'],
      zip_safe=False)
